@@ -1,6 +1,6 @@
 var indexSectionsWithContent =
 {
-  0: ":_abcdefghijklmnopqrstuvwxyz",
+  0: ":abcdefghijklmnopqrstuvwxyz",
   1: "abcdefghijklmnopqrstuvwxyz",
   2: "co",
   3: "abcdefghijklmnopqrstuvwxyz",
@@ -9,7 +9,7 @@ var indexSectionsWithContent =
   6: "abcdefghiklmnoprstuv",
   7: "abcdefghilmnoprstuvwxz",
   8: "abcdefghijklmnopqrstuvwxyz",
-  9: "_",
+  9: "c",
   10: "dlt"
 };
 
